/*
 * Part of Very Secure FTPd
 * Licence: GPL v2
 * Author: Chris Evans
 * utility.c
 */

#include "utility.h"
#include "sysutil.h"
#include "str.h"
#include "defs.h"

#if  1				// 2019/06/14 makabe  for PPG4KS-4000
#include "logging.h"
#include <unistd.h>
#include <errno.h>
extern int xds_pd_access;
extern int xds_sxs1_access;
extern int xds_sxs2_access;
extern int xds_ext_access;
extern int xds_opened_fd;
#endif

#define DIE_DEBUG

void
die(const char* p_text)
{
#if  1				 // 2019/06/14 makabe  for PPG4KS-4000
  DLOG("fd = %d, ma = %d/%d/%d/%d", xds_opened_fd, xds_sxs1_access, xds_sxs2_access, xds_ext_access, xds_pd_access);
  if (xds_opened_fd >= 0)
  {
    while (1) {
      int retval = close(xds_opened_fd);
      if (retval != 0) {
        if (errno == EINTR) {
          vsf_sysutil_check_pending_actions(kVSFSysUtilUnknown, 0, 0);
          continue;
        }
      }
      break;
    }
    xds_opened_fd = -1;
  }
#endif
#ifdef DIE_DEBUG
  bug(p_text);
#endif
  vsf_sysutil_exit(2);
}

void
die2(const char* p_text1, const char* p_text2)
{
  struct mystr die_str = INIT_MYSTR;
  str_alloc_text(&die_str, p_text1);
  if (p_text2)
  {
    str_append_text(&die_str, p_text2);
  }
  else
  {
    str_append_text(&die_str, "(null)");
  }
  die(str_getbuf(&die_str));
}

void
bug(const char* p_text)
{
  /* Rats. Try and write the reason to the network for diagnostics */
  vsf_sysutil_activate_noblock(VSFTP_COMMAND_FD);
  (void) vsf_sysutil_write_loop(VSFTP_COMMAND_FD, "500 OOPS: ", 10);
  (void) vsf_sysutil_write_loop(VSFTP_COMMAND_FD, p_text,
                                vsf_sysutil_strlen(p_text));
  (void) vsf_sysutil_write_loop(VSFTP_COMMAND_FD, "\r\n", 2);
  vsf_sysutil_exit(2);
}

void
vsf_exit(const char* p_text)
{
  (void) vsf_sysutil_write_loop(VSFTP_COMMAND_FD, p_text,
                                vsf_sysutil_strlen(p_text));
  vsf_sysutil_exit(0);
}

